==> helm-annotations-4.0.1-sources.jar: io/dekorate/helm/config/AnnotationFluent.java <==
package io.dekorate.helm.config;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AnnotationFluent<A extends AnnotationFluent<A>> extends BaseFluent<A>{
  public AnnotationFluent() {
  }
  public AnnotationFluent(Annotation instance) {
    instance = (instance != null ? instance : new Annotation());

    if (instance != null) {
      this.withKey(instance.getKey());
      this.withValue(instance.getValue());
    }
  }
  private String key;
  private String value;
  public String getKey() {
    return this.key;
  }
  public A withKey(String key) {
    this.key=key; return (A) this;
  }
  public boolean hasKey() {
    return this.key != null;
  }
  public String getValue() {
    return this.value;
  }
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  public boolean hasValue() {
    return this.value != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AnnotationFluent that = (AnnotationFluent) o;
    if (!java.util.Objects.equals(key, that.key)) return false;

    if (!java.util.Objects.equals(value, that.value)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(key,  value,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (key != null) { sb.append("key:"); sb.append(key + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> helm-annotations-4.1.2-sources.jar: io/dekorate/helm/config/AnnotationFluent.java <==
package io.dekorate.helm.config;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AnnotationFluent<A extends AnnotationFluent<A>> extends BaseFluent<A>{
  public AnnotationFluent() {
  }
  
  public AnnotationFluent(Annotation instance) {
    this.copyInstance(instance);
  }
  private String key;
  private String value;
  
  protected void copyInstance(Annotation instance) {
    instance = (instance != null ? instance : new Annotation());
    if (instance != null) {
          this.withKey(instance.getKey());
          this.withValue(instance.getValue());
        }
  }
  
  public String getKey() {
    return this.key;
  }
  
  public A withKey(String key) {
    this.key = key;
    return (A) this;
  }
  
  public boolean hasKey() {
    return this.key != null;
  }
  
  public String getValue() {
    return this.value;
  }
  
  public A withValue(String value) {
    this.value = value;
    return (A) this;
  }
  
  public boolean hasValue() {
    return this.value != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AnnotationFluent that = (AnnotationFluent) o;
    if (!java.util.Objects.equals(key, that.key)) return false;
    if (!java.util.Objects.equals(value, that.value)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(key,  value,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (key != null) { sb.append("key:"); sb.append(key + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  

}
